==> qtjambi-qt3dextras-debuginfo-linux-x64-5.15.17.jar: sources/QtJambi3DExtras/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_Qt3DExtras_QAbstractCameraController();
void initialize_meta_info_Qt3DExtras_QAbstractCameraController_InputState();
void initialize_meta_info_Qt3DExtras_QAbstractSpriteSheet();
void initialize_meta_info_Qt3DExtras_QConeGeometry();
void initialize_meta_info_Qt3DExtras_QConeMesh();
void initialize_meta_info_Qt3DExtras_QCuboidGeometry();
void initialize_meta_info_Qt3DExtras_QCuboidMesh();
void initialize_meta_info_Qt3DExtras_QCylinderGeometry();
void initialize_meta_info_Qt3DExtras_QCylinderMesh();
void initialize_meta_info_Qt3DExtras_QDiffuseMapMaterial();
void initialize_meta_info_Qt3DExtras_QDiffuseSpecularMapMaterial();
void initialize_meta_info_Qt3DExtras_QDiffuseSpecularMaterial();
void initialize_meta_info_Qt3DExtras_QExtrudedTextGeometry();
void initialize_meta_info_Qt3DExtras_QExtrudedTextMesh();
void initialize_meta_info_Qt3DExtras_QFirstPersonCameraController();
void initialize_meta_info_Qt3DExtras_QForwardRenderer();
void initialize_meta_info_Qt3DExtras_QGoochMaterial();
void initialize_meta_info_Qt3DExtras_QMetalRoughMaterial();
void initialize_meta_info_Qt3DExtras_QMorphPhongMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseMapAlphaMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseMapMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseSpecularMapMaterial();
void initialize_meta_info_Qt3DExtras_QOrbitCameraController();
void initialize_meta_info_Qt3DExtras_QPerVertexColorMaterial();
void initialize_meta_info_Qt3DExtras_QPhongAlphaMaterial();
void initialize_meta_info_Qt3DExtras_QPhongMaterial();
void initialize_meta_info_Qt3DExtras_QPlaneGeometry();
void initialize_meta_info_Qt3DExtras_QPlaneMesh();
void initialize_meta_info_Qt3DExtras_QSkyboxEntity();
void initialize_meta_info_Qt3DExtras_QSphereGeometry();
void initialize_meta_info_Qt3DExtras_QSphereMesh();
void initialize_meta_info_Qt3DExtras_QSpriteGrid();
void initialize_meta_info_Qt3DExtras_QSpriteSheet();
void initialize_meta_info_Qt3DExtras_QSpriteSheetItem();
void initialize_meta_info_Qt3DExtras_QText2DEntity();
void initialize_meta_info_Qt3DExtras_QTextureMaterial();
void initialize_meta_info_Qt3DExtras_QTexturedMetalRoughMaterial();
void initialize_meta_info_Qt3DExtras_QTorusGeometry();
void initialize_meta_info_Qt3DExtras_QTorusMesh();
void initialize_meta_info_Qt3DExtras_Qt3DWindow();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qt3d.extras")
    initialize_meta_info_Qt3DExtras_QAbstractCameraController();
    initialize_meta_info_Qt3DExtras_QAbstractCameraController_InputState();
    initialize_meta_info_Qt3DExtras_QAbstractSpriteSheet();
    initialize_meta_info_Qt3DExtras_QConeGeometry();
    initialize_meta_info_Qt3DExtras_QConeMesh();
    initialize_meta_info_Qt3DExtras_QCuboidGeometry();
    initialize_meta_info_Qt3DExtras_QCuboidMesh();
    initialize_meta_info_Qt3DExtras_QCylinderGeometry();
    initialize_meta_info_Qt3DExtras_QCylinderMesh();
    initialize_meta_info_Qt3DExtras_QDiffuseMapMaterial();
    initialize_meta_info_Qt3DExtras_QDiffuseSpecularMapMaterial();
    initialize_meta_info_Qt3DExtras_QDiffuseSpecularMaterial();
    initialize_meta_info_Qt3DExtras_QExtrudedTextGeometry();
    initialize_meta_info_Qt3DExtras_QExtrudedTextMesh();
    initialize_meta_info_Qt3DExtras_QFirstPersonCameraController();
    initialize_meta_info_Qt3DExtras_QForwardRenderer();
    initialize_meta_info_Qt3DExtras_QGoochMaterial();
    initialize_meta_info_Qt3DExtras_QMetalRoughMaterial();
    initialize_meta_info_Qt3DExtras_QMorphPhongMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseMapAlphaMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseMapMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseSpecularMapMaterial();
    initialize_meta_info_Qt3DExtras_QOrbitCameraController();
    initialize_meta_info_Qt3DExtras_QPerVertexColorMaterial();
    initialize_meta_info_Qt3DExtras_QPhongAlphaMaterial();
    initialize_meta_info_Qt3DExtras_QPhongMaterial();
    initialize_meta_info_Qt3DExtras_QPlaneGeometry();
    initialize_meta_info_Qt3DExtras_QPlaneMesh();
    initialize_meta_info_Qt3DExtras_QSkyboxEntity();
    initialize_meta_info_Qt3DExtras_QSphereGeometry();
    initialize_meta_info_Qt3DExtras_QSphereMesh();
    initialize_meta_info_Qt3DExtras_QSpriteGrid();
    initialize_meta_info_Qt3DExtras_QSpriteSheet();
    initialize_meta_info_Qt3DExtras_QSpriteSheetItem();
    initialize_meta_info_Qt3DExtras_QText2DEntity();
    initialize_meta_info_Qt3DExtras_QTextureMaterial();
    initialize_meta_info_Qt3DExtras_QTexturedMetalRoughMaterial();
    initialize_meta_info_Qt3DExtras_QTorusGeometry();
    initialize_meta_info_Qt3DExtras_QTorusMesh();
    initialize_meta_info_Qt3DExtras_Qt3DWindow();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_extras_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-qt3dextras-debuginfo-linux-x64-6.5.4.jar: sources/QtJambi3DExtras/metainfo.cpp <==
#include <QtJambi/MetaInfo>

void initialize_meta_info_Qt3DExtras_QAbstractCameraController();
void initialize_meta_info_Qt3DExtras_QAbstractCameraController_InputState();
void initialize_meta_info_Qt3DExtras_QAbstractSpriteSheet();
void initialize_meta_info_Qt3DExtras_QConeGeometry();
void initialize_meta_info_Qt3DExtras_QConeGeometryView();
void initialize_meta_info_Qt3DExtras_QConeMesh();
void initialize_meta_info_Qt3DExtras_QCuboidGeometry();
void initialize_meta_info_Qt3DExtras_QCuboidGeometryView();
void initialize_meta_info_Qt3DExtras_QCuboidMesh();
void initialize_meta_info_Qt3DExtras_QCylinderGeometry();
void initialize_meta_info_Qt3DExtras_QCylinderGeometryView();
void initialize_meta_info_Qt3DExtras_QCylinderMesh();
void initialize_meta_info_Qt3DExtras_QDiffuseMapMaterial();
void initialize_meta_info_Qt3DExtras_QDiffuseSpecularMapMaterial();
void initialize_meta_info_Qt3DExtras_QDiffuseSpecularMaterial();
void initialize_meta_info_Qt3DExtras_QExtrudedTextGeometry();
void initialize_meta_info_Qt3DExtras_QExtrudedTextMesh();
void initialize_meta_info_Qt3DExtras_QFirstPersonCameraController();
void initialize_meta_info_Qt3DExtras_QForwardRenderer();
void initialize_meta_info_Qt3DExtras_QGoochMaterial();
void initialize_meta_info_Qt3DExtras_QMetalRoughMaterial();
void initialize_meta_info_Qt3DExtras_QMorphPhongMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseMapAlphaMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseMapMaterial();
void initialize_meta_info_Qt3DExtras_QNormalDiffuseSpecularMapMaterial();
void initialize_meta_info_Qt3DExtras_QOrbitCameraController();
void initialize_meta_info_Qt3DExtras_QPerVertexColorMaterial();
void initialize_meta_info_Qt3DExtras_QPhongAlphaMaterial();
void initialize_meta_info_Qt3DExtras_QPhongMaterial();
void initialize_meta_info_Qt3DExtras_QPlaneGeometry();
void initialize_meta_info_Qt3DExtras_QPlaneGeometryView();
void initialize_meta_info_Qt3DExtras_QPlaneMesh();
void initialize_meta_info_Qt3DExtras_QSkyboxEntity();
void initialize_meta_info_Qt3DExtras_QSphereGeometry();
void initialize_meta_info_Qt3DExtras_QSphereGeometryView();
void initialize_meta_info_Qt3DExtras_QSphereMesh();
void initialize_meta_info_Qt3DExtras_QSpriteGrid();
void initialize_meta_info_Qt3DExtras_QSpriteSheet();
void initialize_meta_info_Qt3DExtras_QSpriteSheetItem();
void initialize_meta_info_Qt3DExtras_QText2DEntity();
void initialize_meta_info_Qt3DExtras_QTextureMaterial();
void initialize_meta_info_Qt3DExtras_QTorusGeometry();
void initialize_meta_info_Qt3DExtras_QTorusGeometryView();
void initialize_meta_info_Qt3DExtras_QTorusMesh();
void initialize_meta_info_Qt3DExtras_Qt3DWindow();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.qt3d.extras")
    initialize_meta_info_Qt3DExtras_QAbstractCameraController();
    initialize_meta_info_Qt3DExtras_QAbstractCameraController_InputState();
    initialize_meta_info_Qt3DExtras_QAbstractSpriteSheet();
    initialize_meta_info_Qt3DExtras_QConeGeometry();
    initialize_meta_info_Qt3DExtras_QConeGeometryView();
    initialize_meta_info_Qt3DExtras_QConeMesh();
    initialize_meta_info_Qt3DExtras_QCuboidGeometry();
    initialize_meta_info_Qt3DExtras_QCuboidGeometryView();
    initialize_meta_info_Qt3DExtras_QCuboidMesh();
    initialize_meta_info_Qt3DExtras_QCylinderGeometry();
    initialize_meta_info_Qt3DExtras_QCylinderGeometryView();
    initialize_meta_info_Qt3DExtras_QCylinderMesh();
    initialize_meta_info_Qt3DExtras_QDiffuseMapMaterial();
    initialize_meta_info_Qt3DExtras_QDiffuseSpecularMapMaterial();
    initialize_meta_info_Qt3DExtras_QDiffuseSpecularMaterial();
    initialize_meta_info_Qt3DExtras_QExtrudedTextGeometry();
    initialize_meta_info_Qt3DExtras_QExtrudedTextMesh();
    initialize_meta_info_Qt3DExtras_QFirstPersonCameraController();
    initialize_meta_info_Qt3DExtras_QForwardRenderer();
    initialize_meta_info_Qt3DExtras_QGoochMaterial();
    initialize_meta_info_Qt3DExtras_QMetalRoughMaterial();
    initialize_meta_info_Qt3DExtras_QMorphPhongMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseMapAlphaMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseMapMaterial();
    initialize_meta_info_Qt3DExtras_QNormalDiffuseSpecularMapMaterial();
    initialize_meta_info_Qt3DExtras_QOrbitCameraController();
    initialize_meta_info_Qt3DExtras_QPerVertexColorMaterial();
    initialize_meta_info_Qt3DExtras_QPhongAlphaMaterial();
    initialize_meta_info_Qt3DExtras_QPhongMaterial();
    initialize_meta_info_Qt3DExtras_QPlaneGeometry();
    initialize_meta_info_Qt3DExtras_QPlaneGeometryView();
    initialize_meta_info_Qt3DExtras_QPlaneMesh();
    initialize_meta_info_Qt3DExtras_QSkyboxEntity();
    initialize_meta_info_Qt3DExtras_QSphereGeometry();
    initialize_meta_info_Qt3DExtras_QSphereGeometryView();
    initialize_meta_info_Qt3DExtras_QSphereMesh();
    initialize_meta_info_Qt3DExtras_QSpriteGrid();
    initialize_meta_info_Qt3DExtras_QSpriteSheet();
    initialize_meta_info_Qt3DExtras_QSpriteSheetItem();
    initialize_meta_info_Qt3DExtras_QText2DEntity();
    initialize_meta_info_Qt3DExtras_QTextureMaterial();
    initialize_meta_info_Qt3DExtras_QTorusGeometry();
    initialize_meta_info_Qt3DExtras_QTorusGeometryView();
    initialize_meta_info_Qt3DExtras_QTorusMesh();
    initialize_meta_info_Qt3DExtras_Qt3DWindow();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_extras_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
